==> huaweicloudsdkgaussdb-3.1.15-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/show_audit_log_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowAuditLogResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'switch_status': 'str'
    }

    attribute_map = {
        'switch_status': 'switch_status'
    }

    def __init__(self, switch_status=None):
        """ShowAuditLogResponse

        The model defined in huaweicloud sdk

        :param switch_status: 审计日志开关状态。取值：ON|OFF
        :type switch_status: str
        """
        
        super(ShowAuditLogResponse, self).__init__()

        self._switch_status = None
        self.discriminator = None

        if switch_status is not None:
            self.switch_status = switch_status

    @property
    def switch_status(self):
        """Gets the switch_status of this ShowAuditLogResponse.

        审计日志开关状态。取值：ON|OFF

        :return: The switch_status of this ShowAuditLogResponse.
        :rtype: str
        """
        return self._switch_status

    @switch_status.setter
    def switch_status(self, switch_status):
        """Sets the switch_status of this ShowAuditLogResponse.

        审计日志开关状态。取值：ON|OFF

        :param switch_status: The switch_status of this ShowAuditLogResponse.
        :type switch_status: str
        """
        self._switch_status = switch_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowAuditLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.1.35-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/show_audit_log_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowAuditLogResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'switch_status': 'str'
    }

    attribute_map = {
        'switch_status': 'switch_status'
    }

    def __init__(self, switch_status=None):
        """ShowAuditLogResponse

        The model defined in huaweicloud sdk

        :param switch_status: 全量SQL开关状态。 取值： - ON，表示开启 - OFF，表示关闭
        :type switch_status: str
        """
        
        super(ShowAuditLogResponse, self).__init__()

        self._switch_status = None
        self.discriminator = None

        if switch_status is not None:
            self.switch_status = switch_status

    @property
    def switch_status(self):
        """Gets the switch_status of this ShowAuditLogResponse.

        全量SQL开关状态。 取值： - ON，表示开启 - OFF，表示关闭

        :return: The switch_status of this ShowAuditLogResponse.
        :rtype: str
        """
        return self._switch_status

    @switch_status.setter
    def switch_status(self, switch_status):
        """Sets the switch_status of this ShowAuditLogResponse.

        全量SQL开关状态。 取值： - ON，表示开启 - OFF，表示关闭

        :param switch_status: The switch_status of this ShowAuditLogResponse.
        :type switch_status: str
        """
        self._switch_status = switch_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowAuditLogResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
